@@ -110,7 +110,7 @@ void ExportNotesJob::slotWriteNextArchiveResource()
             const QString archivePath = Utils::notePath() + identifier + QDir::separator();
 
             QString url = Utils::resourcePath(agent);
-            if (!mAgentPaths.contains(url)) {
+            if (!mAgentPaths.contains(url) && QDir(url).exists()) {
                 mAgentPaths << url;
                 if (!url.isEmpty()) {
                     ExportResourceArchiveJob *resourceJob = new ExportResourceArchiveJob(this);
@@ -145,12 +145,13 @@ void ExportNotesJob::backupConfig()
 
     const QString knotesStr(QStringLiteral("knotesrc"));
     const QString knotesrc = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + knotesStr;
-    backupFile(knotesrc, Utils::configsPath(), knotesStr);
-
+    if (QFileInfo::exists(knotesrc)) {
+        backupFile(knotesrc, Utils::configsPath(), knotesStr);
+    }
     const QString globalNoteSettingsStr(QStringLiteral("globalnotesettings"));
     const QString globalNoteSettingsrc = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + globalNoteSettingsStr;
 
-    if (QFile(globalNoteSettingsrc).exists()) {
+    if (QFileInfo::exists(globalNoteSettingsrc)) {
         KSharedConfigPtr globalnotesettingsrc = KSharedConfig::openConfig(globalNoteSettingsrc);
 
         QTemporaryFile tmp;
