@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -124,7 +124,8 @@ void ShowArchiveStructureDialog::addSubItems(QTreeWidgetItem *parent, const KArc
     const KArchiveDirectory *dir = static_cast<const KArchiveDirectory *>(entry);
     ++indent;
     const QString space = QString(indent * 2, QLatin1Char(' '));
-    Q_FOREACH (const QString &entryName, dir->entries()) {
+    const QStringList lst = dir->entries();
+    for (const QString &entryName : lst) {
         const KArchiveEntry *entry = dir->entry(entryName);
         if (entry) {
             if (entry->isDirectory()) {
